@@ -32,11 +32,11 @@ class TestRand(object):
 
     def test_insufficient_memory(self):
         """
-        `OpenSSL.rand.bytes` raises `MemoryError` if more bytes are requested
-        than will fit in memory.
+        `OpenSSL.rand.bytes` raises `MemoryError` or `OverflowError` if more
+        bytes are requested than will fit in memory.
         """
-        with pytest.raises(MemoryError):
-            rand.bytes(sys.maxsize)
+        with pytest.raises((MemoryError, OverflowError)):
+            rand.bytes(sys.maxsize + 1)
 
     def test_bytes(self):
         """
@@ -100,28 +100,6 @@ class TestRand(object):
         # entropy or not.
         assert rand.status() in (0, 1)
 
-    @pytest.mark.parametrize('args', [
-        (b"foo", 255),
-        (b"foo",),
-    ])
-    def test_egd_warning(self, args):
-        """
-        Calling egd raises :exc:`DeprecationWarning`.
-        """
-        pytest.deprecated_call(rand.egd, *args)
-
-    @pytest.mark.parametrize('args', [
-        (None, 255),
-        (b"foo", None),
-    ])
-    def test_egd_wrong_args(self, args):
-        """
-        `OpenSSL.rand.egd` raises `TypeError` if called with a non-`int`
-        or non-`str` argument.
-        """
-        with pytest.raises(TypeError):
-            rand.egd(*args)
-
     def test_cleanup(self):
         """
         `OpenSSL.rand.cleanup` releases the memory used by the PRNG and
